Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(126)

Unified Diff: remoting/host/desktop_session_proxy.h

Issue 2050353002: Update webrtc::DesktopCapturer clients to implement OnCaptureResult(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix chromeos Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/desktop_session_agent.cc ('k') | remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/desktop_session_proxy.h
diff --git a/remoting/host/desktop_session_proxy.h b/remoting/host/desktop_session_proxy.h
index 133df7c800e9c76fdb812c0f0826f5c5555b18ba..55591463dbbdf45bb21ce136b32a89115883f8b5 100644
--- a/remoting/host/desktop_session_proxy.h
+++ b/remoting/host/desktop_session_proxy.h
@@ -160,8 +160,9 @@ class DesktopSessionProxy
// Drops a cached reference to the shared buffer.
void OnReleaseSharedBuffer(int id);
- // Handles CaptureCompleted notification from the desktop session agent.
- void OnCaptureCompleted(const SerializedDesktopFrame& serialized_frame);
+ // Handles CaptureResult notification from the desktop session agent.
+ void OnCaptureResult(webrtc::DesktopCapturer::Result result,
+ const SerializedDesktopFrame& serialized_frame);
// Handles MouseCursor notification from the desktop session agent.
void OnMouseCursor(const webrtc::MouseCursor& mouse_cursor);
« no previous file with comments | « remoting/host/desktop_session_agent.cc ('k') | remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698